@@ -1,6 +1,7 @@
 from pystrict import strict
 from PyMPDATA import Options
 
+
 @strict
 class Settings:
     def __init__(self):
@@ -17,4 +18,4 @@ class Settings:
         self.options = Options(
             nonoscillatory=True,
             infinite_gauge=True
-        )  # TODO #273: dfl
+        )
